jenkins-bot has submitted this change and it was merged.

Change subject: CommandHelpDialog: Rename 'category' to 'groupName'
......................................................................


CommandHelpDialog: Rename 'category' to 'groupName'

It is called a group everywhere else.

Change-Id: I576e9004d2b29a639683a80ee90373aa774a072b
---
M src/ui/dialogs/ve.ui.CommandHelpDialog.js
1 file changed, 3 insertions(+), 3 deletions(-)

Approvals:
  DLynch: Looks good to me, approved
  jenkins-bot: Verified



diff --git a/src/ui/dialogs/ve.ui.CommandHelpDialog.js 
b/src/ui/dialogs/ve.ui.CommandHelpDialog.js
index 76347d5..e932ebc 100644
--- a/src/ui/dialogs/ve.ui.CommandHelpDialog.js
+++ b/src/ui/dialogs/ve.ui.CommandHelpDialog.js
@@ -232,12 +232,12 @@
  * Register a command for display in the dialog
  *
  * @static
  * @param {string} category The dialog-category in which to display this
  * @param {string} commandName The key for the command; never displayed, but 
used in sorting
  * @param {Object} details The details about the command, used in display
  */
-ve.ui.CommandHelpDialog.static.registerCommand = function ( category, 
commandName, details ) {
-       var group = ve.ui.CommandHelpDialog.static.commandGroups[ category ];
+ve.ui.CommandHelpDialog.static.registerCommand = function ( groupName, 
commandName, details ) {
+       var group = ve.ui.CommandHelpDialog.static.commandGroups[ groupName ];
        if ( !group.commands[ commandName ] ) {
                group.commands[ commandName ] = details;
                return;
@@ -232,12 +232,12 @@
  *
  * @static
- * @param {string} category The dialog-category in which to display this
+ * @param {string} groupName The group in which to display this
  * @param {string} commandName The key for the command; never displayed, but 
used in sorting

-- 
To view, visit https://gerrit.wikimedia.org/r/250661
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: merged
Gerrit-Change-Id: I576e9004d2b29a639683a80ee90373aa774a072b
Gerrit-PatchSet: 1
Gerrit-Project: VisualEditor/VisualEditor
Gerrit-Branch: master
Gerrit-Owner: Esanders <esand...@wikimedia.org>
Gerrit-Reviewer: DLynch <dly...@wikimedia.org>
Gerrit-Reviewer: jenkins-bot <>

_______________________________________________
MediaWiki-commits mailing list
MediaWiki-commits@lists.wikimedia.org
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to